'''
DHT12 (humidity and temperature sensors)
MicroPython driver for micro:bit

AUTHOR: fredscave.com
DATE  : 2025/01
VERSION : 1.00
'''

from microbit import i2c, sleep

ADDR = 0x5C
CMD_MEASURE = bytes([0x00])

def CtoF(Ctemp):
    return round((Ctemp * 9/5) +32, 1)


class DHT12():
    def __init__(self):
        self.data = [None] * 3

    def Read(self):
        attempt = 1
        while (attempt < 4):
            try:
                i2c.write(ADDR, CMD_MEASURE)
                sleep(10)
                buf = i2c.read(ADDR, 5)
            except:
                attempt += 1
                sleep(1000)
            else:
                self.data[0] = DHT12._convertRH(buf)
                self.data[1] = DHT12._convertT(buf)
                self.data[2] = DHT12._checksum(buf)
                return self.data
        self.data[0] = self.data[1] = None
        self.data[2] = False
        return self.data

    def T(self):
        self.Read()
        return self.data[1]

    def RH(self):
        self.Read()
        return int(self.data[0] + 0.5)

    @staticmethod
    def _convertRH(buf):
        RH = buf[0] + buf[1]/10
        return (RH)

    @staticmethod
    def _convertT(buf):
        T = (buf[2] & 0b01111111) + buf[3]/10
        if buf[3] & 0b10000000:
            T = -T
        return T

    @staticmethod
    def _checksum(buf):
        return buf[0]+buf[1]+buf[2]+buf[3] == buf[4]

